summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorJean-Baptiste Queru <jbq@google.com>2012-01-19 17:28:18 -0800
committerAndroid Git Automerger <android-git-automerger@android.com>2012-01-19 17:28:18 -0800
commita1e873975704814416ee4d5023bf0740ec195ec0 (patch)
treeae84d90174818e7a15741507783414722a159695 /core
parentd6b5584b67f8a2f3d8ea20d748652673d5761e33 (diff)
parent7ae84204c14b4abff70fcc19c3c33de2591df34b (diff)
downloadframeworks_base-a1e873975704814416ee4d5023bf0740ec195ec0.zip
frameworks_base-a1e873975704814416ee4d5023bf0740ec195ec0.tar.gz
frameworks_base-a1e873975704814416ee4d5023bf0740ec195ec0.tar.bz2
am 7ae84204: am ba7f0d2a: Merge "Rename (IF_)LOGD(_IF) to (IF_)ALOGD(_IF)"
* commit '7ae84204c14b4abff70fcc19c3c33de2591df34b': Rename (IF_)LOGD(_IF) to (IF_)ALOGD(_IF)
Diffstat (limited to 'core')
-rw-r--r--core/jni/ActivityManager.cpp2
-rw-r--r--core/jni/AndroidRuntime.cpp14
-rw-r--r--core/jni/android/graphics/Canvas.cpp2
-rw-r--r--core/jni/android/graphics/HarfbuzzSkia.cpp2
-rw-r--r--core/jni/android/graphics/TextLayout.cpp8
-rw-r--r--core/jni/android/graphics/TextLayoutCache.cpp64
-rw-r--r--core/jni/android_app_NativeActivity.cpp2
-rw-r--r--core/jni/android_backup_BackupDataInput.cpp4
-rw-r--r--core/jni/android_backup_BackupDataOutput.cpp2
-rw-r--r--core/jni/android_backup_BackupHelperDispatcher.cpp10
-rw-r--r--core/jni/android_bluetooth_BluetoothSocket.cpp4
-rw-r--r--core/jni/android_bluetooth_common.cpp2
-rw-r--r--core/jni/android_database_SQLiteDatabase.cpp4
-rw-r--r--core/jni/android_ddm_DdmHandleNativeHeap.cpp4
-rw-r--r--core/jni/android_hardware_UsbDeviceConnection.cpp2
-rw-r--r--core/jni/android_hardware_UsbRequest.cpp4
-rw-r--r--core/jni/android_net_NetUtils.cpp2
-rw-r--r--core/jni/android_nfc_NdefMessage.cpp6
-rw-r--r--core/jni/android_os_Debug.cpp4
-rw-r--r--core/jni/android_util_Binder.cpp2
-rw-r--r--core/jni/android_util_Process.cpp4
-rw-r--r--core/jni/android_view_GLES20Canvas.cpp2
-rw-r--r--core/jni/android_view_InputQueue.cpp14
-rw-r--r--core/jni/com_android_internal_content_NativeLibraryHelper.cpp8
24 files changed, 86 insertions, 86 deletions
diff --git a/core/jni/ActivityManager.cpp b/core/jni/ActivityManager.cpp
index 0bd14fa..0f9d0bb 100644
--- a/core/jni/ActivityManager.cpp
+++ b/core/jni/ActivityManager.cpp
@@ -48,7 +48,7 @@ int openContentProviderFile(const String16& uri)
}
} else {
// An exception was thrown back; fall through to return failure
- LOGD("openContentUri(%s) caught exception %d\n",
+ ALOGD("openContentUri(%s) caught exception %d\n",
String8(uri).string(), exceptionCode);
}
}
diff --git a/core/jni/AndroidRuntime.cpp b/core/jni/AndroidRuntime.cpp
index 6d1410c..23d36a6 100644
--- a/core/jni/AndroidRuntime.cpp
+++ b/core/jni/AndroidRuntime.cpp
@@ -286,7 +286,7 @@ status_t AndroidRuntime::callMain(const char* className,
JNIEnv* env;
jmethodID methodId;
- LOGD("Calling main entry %s", className);
+ ALOGD("Calling main entry %s", className);
env = getJNIEnv();
if (clazz == NULL || env == NULL) {
@@ -416,7 +416,7 @@ static void readLocale(char* language, char* region)
}
strncat(language, propLang, 2);
strncat(region, propRegn, 2);
- //LOGD("language=%s region=%s\n", language, region);
+ //ALOGD("language=%s region=%s\n", language, region);
}
/*
@@ -629,7 +629,7 @@ int AndroidRuntime::startVm(JavaVM** pJavaVM, JNIEnv** pEnv)
"-agentlib:jdwp=transport=dt_android_adb,suspend=n,server=y";
mOptions.add(opt);
- LOGD("CheckJNI is %s\n", checkJni ? "ON" : "OFF");
+ ALOGD("CheckJNI is %s\n", checkJni ? "ON" : "OFF");
if (checkJni) {
/* extended JNI checking */
opt.optionString = "-Xcheck:jni";
@@ -798,7 +798,7 @@ char* AndroidRuntime::toSlashClassName(const char* className)
*/
void AndroidRuntime::start(const char* className, const char* options)
{
- LOGD("\n>>>>>> AndroidRuntime START %s <<<<<<\n",
+ ALOGD("\n>>>>>> AndroidRuntime START %s <<<<<<\n",
className != NULL ? className : "(unknown)");
blockSigpipe();
@@ -825,7 +825,7 @@ void AndroidRuntime::start(const char* className, const char* options)
}
//const char* kernelHack = getenv("LD_ASSUME_KERNEL");
- //LOGD("Found LD_ASSUME_KERNEL='%s'\n", kernelHack);
+ //ALOGD("Found LD_ASSUME_KERNEL='%s'\n", kernelHack);
/* start the virtual machine */
JNIEnv* env;
@@ -888,7 +888,7 @@ void AndroidRuntime::start(const char* className, const char* options)
}
free(slashClassName);
- LOGD("Shutting down VM\n");
+ ALOGD("Shutting down VM\n");
if (mJavaVM->DetachCurrentThread() != JNI_OK)
LOGW("Warning: unable to detach main thread\n");
if (mJavaVM->DestroyJavaVM() != 0)
@@ -1064,7 +1064,7 @@ static int register_jni_procs(const RegJNIRec array[], size_t count, JNIEnv* env
for (size_t i = 0; i < count; i++) {
if (array[i].mProc(env) < 0) {
#ifndef NDEBUG
- LOGD("----------!!! %s failed to load\n", array[i].mName);
+ ALOGD("----------!!! %s failed to load\n", array[i].mName);
#endif
return -1;
}
diff --git a/core/jni/android/graphics/Canvas.cpp b/core/jni/android/graphics/Canvas.cpp
index 7724646..1362fc8 100644
--- a/core/jni/android/graphics/Canvas.cpp
+++ b/core/jni/android/graphics/Canvas.cpp
@@ -442,7 +442,7 @@ public:
#endif
canvas->drawPicture(*picture);
#ifdef TIME_DRAW
- LOGD("---- picture playback %d ms\n", get_thread_msec() - now);
+ ALOGD("---- picture playback %d ms\n", get_thread_msec() - now);
#endif
}
diff --git a/core/jni/android/graphics/HarfbuzzSkia.cpp b/core/jni/android/graphics/HarfbuzzSkia.cpp
index f6f7b45..29064e0 100644
--- a/core/jni/android/graphics/HarfbuzzSkia.cpp
+++ b/core/jni/android/graphics/HarfbuzzSkia.cpp
@@ -98,7 +98,7 @@ static void glyphsToAdvances(HB_Font hbFont, const HB_Glyph* glyphs, hb_uint32 n
for (unsigned i = 0; i < numGlyphs; ++i) {
advances[i] = SkScalarToHBFixed(scalarAdvances[i]);
#if DEBUG_ADVANCES
- LOGD("glyphsToAdvances -- advances[%d]=%d", i, advances[i]);
+ ALOGD("glyphsToAdvances -- advances[%d]=%d", i, advances[i]);
#endif
}
delete glyphs16;
diff --git a/core/jni/android/graphics/TextLayout.cpp b/core/jni/android/graphics/TextLayout.cpp
index e1398e9..1705768 100644
--- a/core/jni/android/graphics/TextLayout.cpp
+++ b/core/jni/android/graphics/TextLayout.cpp
@@ -350,7 +350,7 @@ void TextLayout::computeAdvancesWithICU(SkPaint* paint, const UChar* chars,
jfloat totalAdvance = 0;
if (widths < count) {
#if DEBUG_ADVANCES
- LOGD("ICU -- count=%d", widths);
+ ALOGD("ICU -- count=%d", widths);
#endif
// Skia operates on code points, not code units, so surrogate pairs return only
// one value. Expand the result so we have one value per UTF-16 code unit.
@@ -367,17 +367,17 @@ void TextLayout::computeAdvancesWithICU(SkPaint* paint, const UChar* chars,
outAdvances[p++] = 0;
}
#if DEBUG_ADVANCES
- LOGD("icu-adv = %f - total = %f", outAdvances[i], totalAdvance);
+ ALOGD("icu-adv = %f - total = %f", outAdvances[i], totalAdvance);
#endif
}
} else {
#if DEBUG_ADVANCES
- LOGD("ICU -- count=%d", count);
+ ALOGD("ICU -- count=%d", count);
#endif
for (size_t i = 0; i < count; i++) {
totalAdvance += outAdvances[i] = SkScalarToFloat(scalarArray[i]);
#if DEBUG_ADVANCES
- LOGD("icu-adv = %f - total = %f", outAdvances[i], totalAdvance);
+ ALOGD("icu-adv = %f - total = %f", outAdvances[i], totalAdvance);
#endif
}
}
diff --git a/core/jni/android/graphics/TextLayoutCache.cpp b/core/jni/android/graphics/TextLayoutCache.cpp
index 4f90bbf..6a81ea2 100644
--- a/core/jni/android/graphics/TextLayoutCache.cpp
+++ b/core/jni/android/graphics/TextLayoutCache.cpp
@@ -47,12 +47,12 @@ void TextLayoutCache::init() {
mDebugLevel = readRtlDebugLevel();
mDebugEnabled = mDebugLevel & kRtlDebugCaches;
- LOGD("Using debug level: %d - Debug Enabled: %d", mDebugLevel, mDebugEnabled);
+ ALOGD("Using debug level: %d - Debug Enabled: %d", mDebugLevel, mDebugEnabled);
mCacheStartTime = systemTime(SYSTEM_TIME_MONOTONIC);
if (mDebugEnabled) {
- LOGD("Initialization is done - Start time: %lld", mCacheStartTime);
+ ALOGD("Initialization is done - Start time: %lld", mCacheStartTime);
}
mInitialized = true;
@@ -89,7 +89,7 @@ void TextLayoutCache::operator()(TextLayoutCacheKey& text, sp<TextLayoutCacheVal
size_t totalSizeToDelete = text.getSize() + desc->getSize();
mSize -= totalSizeToDelete;
if (mDebugEnabled) {
- LOGD("Cache value deleted, size = %d", totalSizeToDelete);
+ ALOGD("Cache value deleted, size = %d", totalSizeToDelete);
}
desc.clear();
}
@@ -138,7 +138,7 @@ sp<TextLayoutCacheValue> TextLayoutCache::getValue(SkPaint* paint,
// Cleanup to make some room if needed
if (mSize + size > mMaxSize) {
if (mDebugEnabled) {
- LOGD("Need to clean some entries for making some room for a new entry");
+ ALOGD("Need to clean some entries for making some room for a new entry");
}
while (mSize + size > mMaxSize) {
// This will call the callback
@@ -157,7 +157,7 @@ sp<TextLayoutCacheValue> TextLayoutCache::getValue(SkPaint* paint,
// Update timing information for statistics
value->setElapsedTime(endTime - startTime);
- LOGD("CACHE MISS: Added entry with "
+ ALOGD("CACHE MISS: Added entry with "
"count=%d, entry size %d bytes, remaining space %d bytes"
" - Compute time in nanos: %d - Text='%s' ",
count, size, mMaxSize - mSize, value->getElapsedTime(),
@@ -165,7 +165,7 @@ sp<TextLayoutCacheValue> TextLayoutCache::getValue(SkPaint* paint,
}
} else {
if (mDebugEnabled) {
- LOGD("CACHE MISS: Calculated but not storing entry because it is too big "
+ ALOGD("CACHE MISS: Calculated but not storing entry because it is too big "
"with start=%d count=%d contextCount=%d, "
"entry size %d bytes, remaining space %d bytes"
" - Compute time in nanos: %lld - Text='%s'",
@@ -183,7 +183,7 @@ sp<TextLayoutCacheValue> TextLayoutCache::getValue(SkPaint* paint,
if (value->getElapsedTime() > 0) {
float deltaPercent = 100 * ((value->getElapsedTime() - elapsedTimeThruCacheGet)
/ ((float)value->getElapsedTime()));
- LOGD("CACHE HIT #%d with start=%d count=%d contextCount=%d"
+ ALOGD("CACHE HIT #%d with start=%d count=%d contextCount=%d"
"- Compute time in nanos: %d - "
"Cache get time in nanos: %lld - Gain in percent: %2.2f - Text='%s' ",
mCacheHitCount, start, count, contextCount,
@@ -201,17 +201,17 @@ sp<TextLayoutCacheValue> TextLayoutCache::getValue(SkPaint* paint,
void TextLayoutCache::dumpCacheStats() {
float remainingPercent = 100 * ((mMaxSize - mSize) / ((float)mMaxSize));
float timeRunningInSec = (systemTime(SYSTEM_TIME_MONOTONIC) - mCacheStartTime) / 1000000000;
- LOGD("------------------------------------------------");
- LOGD("Cache stats");
- LOGD("------------------------------------------------");
- LOGD("pid : %d", getpid());
- LOGD("running : %.0f seconds", timeRunningInSec);
- LOGD("entries : %d", mCache.size());
- LOGD("size : %d bytes", mMaxSize);
- LOGD("remaining : %d bytes or %2.2f percent", mMaxSize - mSize, remainingPercent);
- LOGD("hits : %d", mCacheHitCount);
- LOGD("saved : %lld milliseconds", mNanosecondsSaved / 1000000);
- LOGD("------------------------------------------------");
+ ALOGD("------------------------------------------------");
+ ALOGD("Cache stats");
+ ALOGD("------------------------------------------------");
+ ALOGD("pid : %d", getpid());
+ ALOGD("running : %.0f seconds", timeRunningInSec);
+ ALOGD("entries : %d", mCache.size());
+ ALOGD("size : %d bytes", mMaxSize);
+ ALOGD("remaining : %d bytes or %2.2f percent", mMaxSize - mSize, remainingPercent);
+ ALOGD("hits : %d", mCacheHitCount);
+ ALOGD("saved : %lld milliseconds", mNanosecondsSaved / 1000000);
+ ALOGD("------------------------------------------------");
}
/**
@@ -319,7 +319,7 @@ void TextLayoutCacheValue::computeValues(SkPaint* paint, const UChar* chars,
computeValuesWithHarfbuzz(paint, chars, start, count, contextCount, dirFlags,
&mAdvances, &mTotalAdvance, &mGlyphs);
#if DEBUG_ADVANCES
- LOGD("Advances - start=%d, count=%d, countextCount=%d, totalAdvance=%f", start, count,
+ ALOGD("Advances - start=%d, count=%d, countextCount=%d, totalAdvance=%f", start, count,
contextCount, mTotalAdvance);
#endif
}
@@ -434,14 +434,14 @@ void TextLayoutCacheValue::computeValuesWithHarfbuzz(SkPaint* paint, const UChar
if (bidi) {
UErrorCode status = U_ZERO_ERROR;
#if DEBUG_GLYPHS
- LOGD("computeValuesWithHarfbuzz -- bidiReq=%d", bidiReq);
+ ALOGD("computeValuesWithHarfbuzz -- bidiReq=%d", bidiReq);
#endif
ubidi_setPara(bidi, chars, contextCount, bidiReq, NULL, &status);
if (U_SUCCESS(status)) {
int paraDir = ubidi_getParaLevel(bidi) & kDirection_Mask; // 0 if ltr, 1 if rtl
ssize_t rc = ubidi_countRuns(bidi, &status);
#if DEBUG_GLYPHS
- LOGD("computeValuesWithHarfbuzz -- dirFlags=%d run-count=%d paraDir=%d",
+ ALOGD("computeValuesWithHarfbuzz -- dirFlags=%d run-count=%d paraDir=%d",
dirFlags, rc, paraDir);
#endif
if (U_SUCCESS(status) && rc == 1) {
@@ -489,7 +489,7 @@ void TextLayoutCacheValue::computeValuesWithHarfbuzz(SkPaint* paint, const UChar
isRTL = (runDir == UBIDI_RTL);
jfloat runTotalAdvance = 0;
#if DEBUG_GLYPHS
- LOGD("computeValuesWithHarfbuzz -- run-start=%d run-len=%d isRTL=%d",
+ ALOGD("computeValuesWithHarfbuzz -- run-start=%d run-len=%d isRTL=%d",
startRun, lengthRun, isRTL);
#endif
computeRunValuesWithHarfbuzz(shaperItem, paint,
@@ -515,7 +515,7 @@ void TextLayoutCacheValue::computeValuesWithHarfbuzz(SkPaint* paint, const UChar
// Default single run case
if (useSingleRun){
#if DEBUG_GLYPHS
- LOGD("computeValuesWithHarfbuzz -- Using a SINGLE Run "
+ ALOGD("computeValuesWithHarfbuzz -- Using a SINGLE Run "
"-- run-start=%d run-len=%d isRTL=%d", start, count, isRTL);
#endif
computeRunValuesWithHarfbuzz(shaperItem, paint,
@@ -527,14 +527,14 @@ void TextLayoutCacheValue::computeValuesWithHarfbuzz(SkPaint* paint, const UChar
freeShaperItem(shaperItem);
#if DEBUG_GLYPHS
- LOGD("computeValuesWithHarfbuzz -- total-glyphs-count=%d", outGlyphs->size());
+ ALOGD("computeValuesWithHarfbuzz -- total-glyphs-count=%d", outGlyphs->size());
#endif
}
static void logGlyphs(HB_ShaperItem shaperItem) {
- LOGD("Got glyphs - count=%d", shaperItem.num_glyphs);
+ ALOGD("Got glyphs - count=%d", shaperItem.num_glyphs);
for (size_t i = 0; i < shaperItem.num_glyphs; i++) {
- LOGD(" glyph[%d]=%d - offset.x=%f offset.y=%f", i, shaperItem.glyphs[i],
+ ALOGD(" glyph[%d]=%d - offset.x=%f offset.y=%f", i, shaperItem.glyphs[i],
HBFixedToFloat(shaperItem.offsets[i].x),
HBFixedToFloat(shaperItem.offsets[i].y));
}
@@ -552,17 +552,17 @@ void TextLayoutCacheValue::computeRunValuesWithHarfbuzz(HB_ShaperItem& shaperIte
shapeRun(shaperItem, start, count, isRTL);
#if DEBUG_GLYPHS
- LOGD("HARFBUZZ -- num_glypth=%d - kerning_applied=%d", shaperItem.num_glyphs,
+ ALOGD("HARFBUZZ -- num_glypth=%d - kerning_applied=%d", shaperItem.num_glyphs,
shaperItem.kerning_applied);
- LOGD(" -- string= '%s'", String8(shaperItem.string + start, count).string());
- LOGD(" -- isDevKernText=%d", paint->isDevKernText());
+ ALOGD(" -- string= '%s'", String8(shaperItem.string + start, count).string());
+ ALOGD(" -- isDevKernText=%d", paint->isDevKernText());
logGlyphs(shaperItem);
#endif
if (shaperItem.advances == NULL || shaperItem.num_glyphs == 0) {
#if DEBUG_GLYPHS
- LOGD("HARFBUZZ -- advances array is empty or num_glypth = 0");
+ ALOGD("HARFBUZZ -- advances array is empty or num_glypth = 0");
#endif
outAdvances->insertAt(0, outAdvances->size(), count);
*outTotalAdvance = 0;
@@ -588,7 +588,7 @@ void TextLayoutCacheValue::computeRunValuesWithHarfbuzz(HB_ShaperItem& shaperIte
#if DEBUG_ADVANCES
for (size_t i = 0; i < count; i++) {
- LOGD("hb-adv[%d] = %f - log_clusters = %d - total = %f", i,
+ ALOGD("hb-adv[%d] = %f - log_clusters = %d - total = %f", i,
(*outAdvances)[i], shaperItem.log_clusters[i], totalAdvance);
}
#endif
@@ -599,7 +599,7 @@ void TextLayoutCacheValue::computeRunValuesWithHarfbuzz(HB_ShaperItem& shaperIte
for (size_t i = 0; i < countGlyphs; i++) {
jchar glyph = (jchar) shaperItem.glyphs[(!isRTL) ? i : countGlyphs - 1 - i];
#if DEBUG_GLYPHS
- LOGD("HARFBUZZ -- glyph[%d]=%d", i, glyph);
+ ALOGD("HARFBUZZ -- glyph[%d]=%d", i, glyph);
#endif
outGlyphs->add(glyph);
}
diff --git a/core/jni/android_app_NativeActivity.cpp b/core/jni/android_app_NativeActivity.cpp
index c43e7e7..15bb543 100644
--- a/core/jni/android_app_NativeActivity.cpp
+++ b/core/jni/android_app_NativeActivity.cpp
@@ -1060,7 +1060,7 @@ static const char* const kNativeActivityPathName = "android/app/NativeActivity";
int register_android_app_NativeActivity(JNIEnv* env)
{
- //LOGD("register_android_app_NativeActivity");
+ //ALOGD("register_android_app_NativeActivity");
jclass clazz;
FIND_CLASS(clazz, kNativeActivityPathName);
diff --git a/core/jni/android_backup_BackupDataInput.cpp b/core/jni/android_backup_BackupDataInput.cpp
index c174a41..2fb0076 100644
--- a/core/jni/android_backup_BackupDataInput.cpp
+++ b/core/jni/android_backup_BackupDataInput.cpp
@@ -80,7 +80,7 @@ readNextHeader_native(JNIEnv* env, jobject clazz, int r, jobject entity)
return 0;
}
default:
- LOGD("Unknown header type: 0x%08x\n", type);
+ ALOGD("Unknown header type: 0x%08x\n", type);
return -1;
}
@@ -133,7 +133,7 @@ static const JNINativeMethod g_methods[] = {
int register_android_backup_BackupDataInput(JNIEnv* env)
{
- //LOGD("register_android_backup_BackupDataInput");
+ //ALOGD("register_android_backup_BackupDataInput");
jclass clazz = env->FindClass("android/app/backup/BackupDataInput$EntityHeader");
LOG_FATAL_IF(clazz == NULL, "Unable to find class android.app.backup.BackupDataInput.EntityHeader");
diff --git a/core/jni/android_backup_BackupDataOutput.cpp b/core/jni/android_backup_BackupDataOutput.cpp
index 144a10c..f4b5dca 100644
--- a/core/jni/android_backup_BackupDataOutput.cpp
+++ b/core/jni/android_backup_BackupDataOutput.cpp
@@ -107,7 +107,7 @@ static const JNINativeMethod g_methods[] = {
int register_android_backup_BackupDataOutput(JNIEnv* env)
{
- //LOGD("register_android_backup_BackupDataOutput");
+ //ALOGD("register_android_backup_BackupDataOutput");
return AndroidRuntime::registerNativeMethods(env, "android/app/backup/BackupDataOutput",
g_methods, NELEM(g_methods));
}
diff --git a/core/jni/android_backup_BackupHelperDispatcher.cpp b/core/jni/android_backup_BackupHelperDispatcher.cpp
index 49f1cd4..1f188ff 100644
--- a/core/jni/android_backup_BackupHelperDispatcher.cpp
+++ b/core/jni/android_backup_BackupHelperDispatcher.cpp
@@ -85,11 +85,11 @@ readHeader_native(JNIEnv* env, jobject clazz, jobject headerObj, jobject fdObj)
}
#if 0
- LOGD("chunk header:");
- LOGD(" headerSize=%d", flattenedHeader.headerSize);
- LOGD(" version=0x%08x", flattenedHeader.version);
- LOGD(" dataSize=%d", flattenedHeader.dataSize);
- LOGD(" nameLength=%d", flattenedHeader.nameLength);
+ ALOGD("chunk header:");
+ ALOGD(" headerSize=%d", flattenedHeader.headerSize);
+ ALOGD(" version=0x%08x", flattenedHeader.version);
+ ALOGD(" dataSize=%d", flattenedHeader.dataSize);
+ ALOGD(" nameLength=%d", flattenedHeader.nameLength);
#endif
if (flattenedHeader.dataSize < 0 || flattenedHeader.nameLength < 0 ||
diff --git a/core/jni/android_bluetooth_BluetoothSocket.cpp b/core/jni/android_bluetooth_BluetoothSocket.cpp
index 32ceb2c..d9ff36a 100644
--- a/core/jni/android_bluetooth_BluetoothSocket.cpp
+++ b/core/jni/android_bluetooth_BluetoothSocket.cpp
@@ -240,7 +240,7 @@ connect:
* retry the connect. Unfortunately we have to create a new fd.
* It's not ideal to switch the fd underneath the object, but
* is currently safe */
- LOGD("Hit bug 5082381 (EALREADY on ACL collision), trying workaround");
+ ALOGD("Hit bug 5082381 (EALREADY on ACL collision), trying workaround");
usleep(100000);
retry++;
abortNative(env, obj);
@@ -252,7 +252,7 @@ connect:
goto connect;
}
if (!ret && retry > 0)
- LOGD("...workaround ok");
+ ALOGD("...workaround ok");
if (ret)
jniThrowIOException(env, errno);
diff --git a/core/jni/android_bluetooth_common.cpp b/core/jni/android_bluetooth_common.cpp
index a3e99cb..c8dc9c2 100644
--- a/core/jni/android_bluetooth_common.cpp
+++ b/core/jni/android_bluetooth_common.cpp
@@ -855,7 +855,7 @@ bool debug_no_encrypt() {
property_get("debug.bt.no_encrypt", value, "");
if (!strncmp("true", value, PROPERTY_VALUE_MAX) ||
!strncmp("1", value, PROPERTY_VALUE_MAX)) {
- LOGD("mandatory bluetooth encryption disabled");
+ ALOGD("mandatory bluetooth encryption disabled");
return true;
} else {
return false;
diff --git a/core/jni/android_database_SQLiteDatabase.cpp b/core/jni/android_database_SQLiteDatabase.cpp
index 605a11c..2966a71 100644
--- a/core/jni/android_database_SQLiteDatabase.cpp
+++ b/core/jni/android_database_SQLiteDatabase.cpp
@@ -439,7 +439,7 @@ static jint native_addCustomFunction(JNIEnv* env, jobject object,
sqlite3 * handle = (sqlite3 *)env->GetIntField(object, offset_db_handle);
char const *nameStr = env->GetStringUTFChars(name, NULL);
jobject ref = env->NewGlobalRef(function);
- LOGD_IF(DEBUG_JNI, "native_addCustomFunction %s ref: %p", nameStr, ref);
+ ALOGD_IF(DEBUG_JNI, "native_addCustomFunction %s ref: %p", nameStr, ref);
int err = sqlite3_create_function(handle, nameStr, numArgs, SQLITE_UTF8,
(void *)ref, custom_function_callback, NULL, NULL);
env->ReleaseStringUTFChars(name, nameStr);
@@ -456,7 +456,7 @@ static jint native_addCustomFunction(JNIEnv* env, jobject object,
static void native_releaseCustomFunction(JNIEnv* env, jobject object, jint ref)
{
- LOGD_IF(DEBUG_JNI, "native_releaseCustomFunction %d", ref);
+ ALOGD_IF(DEBUG_JNI, "native_releaseCustomFunction %d", ref);
env->DeleteGlobalRef((jobject)ref);
}
diff --git a/core/jni/android_hardware_UsbDeviceConnection.cpp b/core/jni/android_hardware_UsbDeviceConnection.cpp
index 68be9e1..f53e2f7 100644
--- a/core/jni/android_hardware_UsbDeviceConnection.cpp
+++ b/core/jni/android_hardware_UsbDeviceConnection.cpp
@@ -64,7 +64,7 @@ android_hardware_UsbDeviceConnection_open(JNIEnv *env, jobject thiz, jstring dev
static void
android_hardware_UsbDeviceConnection_close(JNIEnv *env, jobject thiz)
{
- LOGD("close\n");
+ ALOGD("close\n");
struct usb_device* device = get_device_from_object(env, thiz);
if (device) {
usb_device_close(device);
diff --git a/core/jni/android_hardware_UsbRequest.cpp b/core/jni/android_hardware_UsbRequest.cpp
index 6bd67d1..6e1d443 100644
--- a/core/jni/android_hardware_UsbRequest.cpp
+++ b/core/jni/android_hardware_UsbRequest.cpp
@@ -42,7 +42,7 @@ static jboolean
android_hardware_UsbRequest_init(JNIEnv *env, jobject thiz, jobject java_device,
jint ep_address, jint ep_attributes, jint ep_max_packet_size, jint ep_interval)
{
- LOGD("init\n");
+ ALOGD("init\n");
struct usb_device* device = get_device_from_object(env, java_device);
if (!device) {
@@ -68,7 +68,7 @@ android_hardware_UsbRequest_init(JNIEnv *env, jobject thiz, jobject java_device,
static void
android_hardware_UsbRequest_close(JNIEnv *env, jobject thiz)
{
- LOGD("close\n");
+ ALOGD("close\n");
struct usb_request* request = get_request_from_object(env, thiz);
if (request) {
usb_request_free(request);
diff --git a/core/jni/android_net_NetUtils.cpp b/core/jni/android_net_NetUtils.cpp
index d9bd50e..724d9fb 100644
--- a/core/jni/android_net_NetUtils.cpp
+++ b/core/jni/android_net_NetUtils.cpp
@@ -97,7 +97,7 @@ static jint android_net_utils_resetConnections(JNIEnv* env, jobject clazz,
const char *nameStr = env->GetStringUTFChars(ifname, NULL);
- LOGD("android_net_utils_resetConnections in env=%p clazz=%p iface=%s mask=0x%x\n",
+ ALOGD("android_net_utils_resetConnections in env=%p clazz=%p iface=%s mask=0x%x\n",
env, clazz, nameStr, mask);
result = ::ifc_reset_connections(nameStr, mask);
diff --git a/core/jni/android_nfc_NdefMessage.cpp b/core/jni/android_nfc_NdefMessage.cpp
index 41099cb..82476cd 100644
--- a/core/jni/android_nfc_NdefMessage.cpp
+++ b/core/jni/android_nfc_NdefMessage.cpp
@@ -117,19 +117,19 @@ static jint android_nfc_NdefMessage_parseNdefMessage(JNIEnv *e, jobject o,
type = e->NewByteArray(record.TypeLength);
if (type == NULL) {
- LOGD("NFC_Set Record Type Error\n");
+ ALOGD("NFC_Set Record Type Error\n");
goto end;
}
id = e->NewByteArray(record.IdLength);
if(id == NULL) {
- LOGD("NFC_Set Record ID Error\n");
+ ALOGD("NFC_Set Record ID Error\n");
goto end;
}
payload = e->NewByteArray(record.PayloadLength);
if(payload == NULL) {
- LOGD("NFC_Set Record Payload Error\n");
+ ALOGD("NFC_Set Record Payload Error\n");
goto end;
}
diff --git a/core/jni/android_os_Debug.cpp b/core/jni/android_os_Debug.cpp
index 85fac5f..f8dc618 100644
--- a/core/jni/android_os_Debug.cpp
+++ b/core/jni/android_os_Debug.cpp
@@ -530,9 +530,9 @@ static void android_os_Debug_dumpNativeHeap(JNIEnv* env, jobject clazz,
return;
}
- LOGD("Native heap dump starting...\n");
+ ALOGD("Native heap dump starting...\n");
dumpNativeHeap(fp);
- LOGD("Native heap dump complete.\n");
+ ALOGD("Native heap dump complete.\n");
fclose(fp);
}
diff --git a/core/jni/android_util_Binder.cpp b/core/jni/android_util_Binder.cpp
index bd62268..9e3d04a 100644
--- a/core/jni/android_util_Binder.cpp
+++ b/core/jni/android_util_Binder.cpp
@@ -50,7 +50,7 @@
#define DEBUG_DEATH 0
#if DEBUG_DEATH
-#define LOGDEATH LOGD
+#define LOGDEATH ALOGD
#else
#define LOGDEATH ALOGV
#endif
diff --git a/core/jni/android_util_Process.cpp b/core/jni/android_util_Process.cpp
index e7626bc..bc7e47c 100644
--- a/core/jni/android_util_Process.cpp
+++ b/core/jni/android_util_Process.cpp
@@ -205,9 +205,9 @@ void android_os_Process_setProcessGroup(JNIEnv* env, jobject clazz, int pid, jin
}
if (grp == ANDROID_TGROUP_BG_NONINTERACT) {
- LOGD("setProcessGroup: vvv pid %d (%s)", pid, cmdline);
+ ALOGD("setProcessGroup: vvv pid %d (%s)", pid, cmdline);
} else {
- LOGD("setProcessGroup: ^^^ pid %d (%s)", pid, cmdline);
+ ALOGD("setProcessGroup: ^^^ pid %d (%s)", pid, cmdline);
}
#endif
sprintf(proc_path, "/proc/%d/task", pid);
diff --git a/core/jni/android_view_GLES20Canvas.cpp b/core/jni/android_view_GLES20Canvas.cpp
index 426f4f7..d0c6be7 100644
--- a/core/jni/android_view_GLES20Canvas.cpp
+++ b/core/jni/android_view_GLES20Canvas.cpp
@@ -66,7 +66,7 @@ using namespace uirenderer;
// Debug
#if DEBUG_RENDERER
- #define RENDERER_LOGD(...) LOGD(__VA_ARGS__)
+ #define RENDERER_LOGD(...) ALOGD(__VA_ARGS__)
#else
#define RENDERER_LOGD(...)
#endif
diff --git a/core/jni/android_view_InputQueue.cpp b/core/jni/android_view_InputQueue.cpp
index 300c04a..d44dbc0 100644
--- a/core/jni/android_view_InputQueue.cpp
+++ b/core/jni/android_view_InputQueue.cpp
@@ -138,7 +138,7 @@ status_t NativeInputQueue::registerInputChannel(JNIEnv* env, jobject inputChanne
}
#if DEBUG_REGISTRATION
- LOGD("channel '%s' - Registered", inputChannel->getName().string());
+ ALOGD("channel '%s' - Registered", inputChannel->getName().string());
#endif
sp<Looper> looper = android_os_MessageQueue_getLooper(env, messageQueueObj);
@@ -183,7 +183,7 @@ status_t NativeInputQueue::unregisterInputChannel(JNIEnv* env, jobject inputChan
}
#if DEBUG_REGISTRATION
- LOGD("channel '%s' - Unregistered", inputChannel->getName().string());
+ ALOGD("channel '%s' - Unregistered", inputChannel->getName().string());
#endif
{ // acquire lock
@@ -277,7 +277,7 @@ status_t NativeInputQueue::finished(JNIEnv* env, jlong finishedToken,
}
#if DEBUG_DISPATCH_CYCLE
- LOGD("channel '%s' ~ Finished event.",
+ ALOGD("channel '%s' ~ Finished event.",
connection->getInputChannelName());
#endif
} // release lock
@@ -369,7 +369,7 @@ int NativeInputQueue::handleReceiveCallback(int receiveFd, int events, void* dat
switch (inputEventType) {
case AINPUT_EVENT_TYPE_KEY:
#if DEBUG_DISPATCH_CYCLE
- LOGD("channel '%s' ~ Received key event.", connection->getInputChannelName());
+ ALOGD("channel '%s' ~ Received key event.", connection->getInputChannelName());
#endif
inputEventObj = android_view_KeyEvent_fromNative(env,
static_cast<KeyEvent*>(inputEvent));
@@ -378,7 +378,7 @@ int NativeInputQueue::handleReceiveCallback(int receiveFd, int events, void* dat
case AINPUT_EVENT_TYPE_MOTION:
#if DEBUG_DISPATCH_CYCLE
- LOGD("channel '%s' ~ Received motion event.", connection->getInputChannelName());
+ ALOGD("channel '%s' ~ Received motion event.", connection->getInputChannelName());
#endif
inputEventObj = android_view_MotionEvent_obtainAsCopy(env,
static_cast<MotionEvent*>(inputEvent));
@@ -399,13 +399,13 @@ int NativeInputQueue::handleReceiveCallback(int receiveFd, int events, void* dat
}
#if DEBUG_DISPATCH_CYCLE
- LOGD("Invoking input handler.");
+ ALOGD("Invoking input handler.");
#endif
env->CallStaticVoidMethod(gInputQueueClassInfo.clazz,
dispatchMethodId, inputHandlerObjLocal, inputEventObj,
jlong(finishedToken));
#if DEBUG_DISPATCH_CYCLE
- LOGD("Returned from input handler.");
+ ALOGD("Returned from input handler.");
#endif
if (env->ExceptionCheck()) {
diff --git a/core/jni/com_android_internal_content_NativeLibraryHelper.cpp b/core/jni/com_android_internal_content_NativeLibraryHelper.cpp
index 97a729e..ae8cae9 100644
--- a/core/jni/com_android_internal_content_NativeLibraryHelper.cpp
+++ b/core/jni/com_android_internal_content_NativeLibraryHelper.cpp
@@ -174,7 +174,7 @@ copyFileIfChanged(JNIEnv *env, void* arg, ZipFileRO* zipFile, ZipEntryRO zipEntr
time_t modTime;
if (!zipFile->getEntryInfo(zipEntry, NULL, &uncompLen, NULL, NULL, &when, &crc)) {
- LOGD("Couldn't read zip entry info\n");
+ ALOGD("Couldn't read zip entry info\n");
return INSTALL_FAILED_INVALID_APK;
} else {
struct tm t;
@@ -187,7 +187,7 @@ copyFileIfChanged(JNIEnv *env, void* arg, ZipFileRO* zipFile, ZipEntryRO zipEntr
char localFileName[nativeLibPath.size() + fileNameLen + 2];
if (strlcpy(localFileName, nativeLibPath.c_str(), sizeof(localFileName)) != nativeLibPath.size()) {
- LOGD("Couldn't allocate local file name for library");
+ ALOGD("Couldn't allocate local file name for library");
return INSTALL_FAILED_INTERNAL_ERROR;
}
@@ -195,7 +195,7 @@ copyFileIfChanged(JNIEnv *env, void* arg, ZipFileRO* zipFile, ZipEntryRO zipEntr
if (strlcpy(localFileName + nativeLibPath.size() + 1, fileName, sizeof(localFileName)
- nativeLibPath.size() - 1) != fileNameLen) {
- LOGD("Couldn't allocate local file name for library");
+ ALOGD("Couldn't allocate local file name for library");
return INSTALL_FAILED_INTERNAL_ERROR;
}
@@ -208,7 +208,7 @@ copyFileIfChanged(JNIEnv *env, void* arg, ZipFileRO* zipFile, ZipEntryRO zipEntr
char localTmpFileName[nativeLibPath.size() + TMP_FILE_PATTERN_LEN + 2];
if (strlcpy(localTmpFileName, nativeLibPath.c_str(), sizeof(localTmpFileName))
!= nativeLibPath.size()) {
- LOGD("Couldn't allocate local file name for library");
+ ALOGD("Couldn't allocate local file name for library");
return INSTALL_FAILED_INTERNAL_ERROR;
}
diff --git a/core/jni/android_ddm_DdmHandleNativeHeap.cpp b/core/jni/android_ddm_DdmHandleNativeHeap.cpp
index c3b4e3c..42d408d 100644
--- a/core/jni/android_ddm_DdmHandleNativeHeap.cpp
+++ b/core/jni/android_ddm_DdmHandleNativeHeap.cpp
@@ -87,7 +87,7 @@ static jbyteArray getLeakInfo(JNIEnv *env, jobject clazz)
header.mapSize += amount;
} while (header.mapSize < MAPS_FILE_SIZE);
- LOGD("**** read %d bytes from '%s'", (int) header.mapSize, path);
+ ALOGD("**** read %d bytes from '%s'", (int) header.mapSize, path);
}
}
@@ -105,7 +105,7 @@ static jbyteArray getLeakInfo(JNIEnv *env, jobject clazz)
bytes = env->GetByteArrayElements(array, NULL);
ptr = bytes;
// LOGD("*** mapSize: %d allocSize: %d allocInfoSize: %d totalMemory: %d",
// header.mapSize, header.allocSize, header.allocInfoSize, header.totalMemory);
memcpy(ptr, &header, sizeof(header));
@@ -105,7 +105,7 @@ static jbyteArray getLeakInfo(JNIEnv *env, jobject clazz)
bytes = env->GetByteArrayElements(array, NULL);
ptr = bytes;
-// LOGD("*** mapSize: %d allocSize: %d allocInfoSize: %d totalMemory: %d",
+// ALOGD("*** mapSize: %d allocSize: %d allocInfoSize: %d totalMemory: %d",
// header.mapSize, header.allocSize, header.allocInfoSize, header.totalMemory);
memcpy(ptr, &header, sizeof(header));